app.component('product-display', {
    template:
        `<div class="product-display">
      <div class="product-container">
        <div class="product-image">
          <img v-bind:src="image">
        </div>
        <div class="product-info">
          <h1>{{ title }}</h1>
          <p>Livraison: {{ shipping }}</p>
          <p v-if="inStock">En stock</p>
          <p v-else>En rupture</p>
  
          <div class="variants-wrapper">
              <div 
                v-for="(variant, index) in variants" 
                :key="variant.id" 
                @mouseover="updateVariant(index)" 
                class="color-circle" 
                :style="{ backgroundColor: variant.color }">
              </div>
          </div>
          <button 
            class="button" 
            :class="{ disabledButton: !inStock }" 
            :disabled="!inStock" 
            v-on:click="addToCart">
            Ajouter au panier
          </button>
        </div>
      </div>
    </div>`,
    data() {
        return {
            product: 'T-Shirt',
            brand: 'Gekkode',
            selectedVariant: 0,
            details: ['60% coton', '30% laine', '10% polyester'],
            variants: [
                { id: 2234, color: '#0000FF', image: './assets/images/t-shirt-bleu.png', quantity: 20 },
                { id: 2235, color: '#FF0000', image: './assets/images/t-shirt-rouge.png', quantity: 0 }
            ]
        }
    },
    props: {
        premium: {
            type: Boolean,
            required: true
        }
    },
    methods: {
        addToCart() {
            this.$emit('add-to-cart', this.variants[this.selectedVariant].id)
        },
        updateVariant(index) {
            this.selectedVariant = index
        }
    },
    computed: {
        title() {
            return this.brand + ' ' + this.product
        },
        image() {
            return this.variants[this.selectedVariant].image
        },
        inStock() {
            return this.variants[this.selectedVariant].quantity
        },
        shipping() {
            if (this.premium) {
                return 'Gratuit'
            }
            return 2.99+"€"
        }
    }
})
